@@ -117,12 +117,18 @@
 #' # for better estimation.
 #' #
 #' # The input data here is simulated from 10 mutational signatures
-#' e1 <- bp_extract_signatures(
-#'   t(simulated_catalogs$set1),
-#'   range = 8:12,
-#'   n_bootstrap = 5,
-#'   n_nmf_run = 10
-#' )
+#'
+#' # e1 <- bp_extract_signatures(
+#' #   t(simulated_catalogs$set1),
+#' #   range = 8:12,
+#' #   n_bootstrap = 5,
+#' #   n_nmf_run = 10
+#' # )
+#' #
+#' # To avoid computation in examples,
+#' # Here just load the result
+#' # (e1$signature and e1$exposure set to NA to reduce package size)
+#' load(system.file("extdata", "e1.RData", package = "sigminer"))
 #'
 #'
 #' # See the survey for different signature numbers
@@ -164,7 +170,9 @@
 #' # NOTE: the optimization step may not truly optimize the result!
 #' expo <- bp_attribute_activity(e1, return_class = "data.table")
 #' expo$abs_activity
+#' }
 #'
+#' \dontrun{
 #' # Iterative extraction:
 #' # This procedure will rerun extraction step
 #' # for those samples with reconstructed catalog similarity
@@ -191,7 +199,6 @@
 #' }
 #' @testexamples
 #' expect_is(e1, "ExtractionResult")
-#' expect_is(e2, "ExtractionResultList")
 #' expect_is(p1, "ggplot")
 #' expect_is(p2, "ggplot")
 #' expect_is(p2, "ggplot")
@@ -200,8 +207,6 @@
 #' expect_is(sim, "list")
 #' expect_is(rec_sim, "data.table")
 #' expect_is(expo, "list")
-#' expect_is(rank_score, "data.frame")
-#' expect_is(stats, "list")
 NULL
 
 #' @rdname bp
@@ -1273,9 +1278,14 @@ env_install <- function(use_conda, py_path, pkg, pkg_version) {
         }
         message("Conda environment not detected, creat it and install required packages.")
         message("======")
-        reticulate::conda_create("sigminer_sigprofiler")
+        reticulate::conda_create("sigminer_sigprofiler", packages = "python=3.7")
         message("Installing packages, be patient...")
         message("======")
+        # reticulate::conda_install("sigminer_sigprofiler",
+        #                           packages = "torch==1.5.1",
+        #                           pip = TRUE,
+        #                           pip_options = "-f https://download.pytorch.org/whl/torch_stable.html"
+        # )
         reticulate::conda_install("sigminer_sigprofiler",
           packages = paste0(pkg, "==", pkg_version),
           pip = TRUE
